@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import {
@@ -18,7 +19,7 @@ import fetch from 'cross-fetch'
 import { withClientState } from 'apollo-link-state'
 import { RetryLink } from 'apollo-link-retry'
 import { onError } from 'apollo-link-error'
-import lodash from 'lodash'
+import _ from 'lodash'
 import gql from 'graphql-tag'
 import config from '../shared/config'
 import * as Query from './queries'
@@ -246,13 +247,22 @@ class apolloClient {
 
   // gets list
   get(resourceType, variables = {}) {
-    const resourceList = lodash.get(Query, resourceType.list)
+    const resourceList = _.get(Query, resourceType.list)
     if (resourceList) {
       return searchClient.query({ query: resourceList, variables })
     }
     return Promise.resolve()
   }
 
+  // gets fallback to console-api
+  fallback(resourceType, variables = {}) {
+    const resourceFallback = _.get(Query, resourceType.fallback)
+    if (resourceFallback) {
+      return client.query({ query: resourceFallback, variables })
+    }
+    return Promise.resolve()
+  }
+
   // Determines if user is able to perform a particular action on a resource
   getUserAccess(variables) {
     return client.query({ query: Query.userAccess, variables })
@@ -278,10 +288,25 @@ class apolloClient {
     return client.query({ query: Query.gitChannelPaths, variables })
   }
 
+  // get Argo app route
+  getArgoAppRouteURL(variables) {
+    return client.query({ query: Query.argoAppRouteURL, variables })
+  }
+
+  // get managed cluster status
+  getManagedClusterStatus(variables) {
+    return client.query({ query: Query.managedClusterStatus, variables })
+  }
+
+  // get Route resource url
+  getRouteResourceURL(variables) {
+    return client.query({ query: Query.routeResourceURL, variables })
+  }
+
   // gets one resource
   getResource(resourceType, variables = {}) {
     return client.query({
-      query: lodash.get(Query, resourceType.name),
+      query: _.get(Query, resourceType.name),
       variables
     })
   }
