@@ -1,21 +1,23 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import gql from 'graphql-tag'
 
-export const ApplicationsList = gql`
+export const QueryApplicationList = gql`
   query applicationsList {
     applications {
       _uid
+      apiVersion
       name
-      selfLink
       namespace
+      cluster
       dashboard
       clusterCount
       hubChannels
@@ -28,16 +30,22 @@ export const ApplicationsList = gql`
         channel
       }
       created
+      applicationSet
+      destinationCluster
+      destinationNamespace
+      repoURL
+      path
+      chart
+      targetRevision
     }
   }
 `
 
-export const SubscriptionsList = gql`
+export const QuerySubscriptionList = gql`
   query subscriptionsList {
     subscriptions {
       _uid
       name
-      selfLink
       namespace
       appCount
       clusterCount
@@ -50,12 +58,11 @@ export const SubscriptionsList = gql`
   }
 `
 
-export const PlacementRulesList = gql`
+export const QueryPlacementRuleList = gql`
   query placementRulesList {
     placementRules {
       _uid
       name
-      selfLink
       namespace
       clusterCount
       replicas
@@ -64,12 +71,11 @@ export const PlacementRulesList = gql`
   }
 `
 
-export const ChannelsList = gql`
+export const QueryChannelList = gql`
   query channelsList {
     channels {
       _uid
       name
-      selfLink
       namespace
       subscriptionCount
       clusterCount
@@ -194,16 +200,53 @@ export const gitChannelPaths = gql`
     )
   }
 `
+export const argoAppRouteURL = gql`
+  query getArgoAppRouteURL(
+    $cluster: String!
+    $namespace: String!
+    $name: String!
+    $apiVersion: String!
+  ) {
+    argoAppRouteURL(
+      cluster: $cluster
+      namespace: $namespace
+      name: $name
+      apiVersion: $apiVersion
+    )
+  }
+`
 
-export const HCMSecretsList = gql`
-  query getSecrets($namespace: String!) {
-    secrets(namespace: $namespace) {
-      name
-      namespace
+export const HCMAnsibleTower = gql`
+  query getSecrets($label: String!, $value: String!) {
+    secrets(label: $label, value: $value) {
+      ansibleSecretName
+      ansibleSecretNamespace
     }
   }
 `
 
+export const managedClusterStatus = gql`
+  query getManagedCluster($clusterName: String!) {
+    isManagedClusterConditionAvailable(clusterName: $clusterName)
+  }
+`
+
+export const routeResourceURL = gql`
+  query getRouteResourceURL(
+    $cluster: String!
+    $namespace: String!
+    $name: String!
+    $apiVersion: String!
+  ) {
+    routeResourceURL(
+      cluster: $cluster
+      namespace: $namespace
+      name: $name
+      apiVersion: $apiVersion
+    )
+  }
+`
+
 export const HCMContainer = gql`
   query getResource(
     $selfLink: String
@@ -277,6 +320,23 @@ export const getApplication = gql`
   }
 `
 
+export const getApplications = gql`
+  query getApplications {
+    applications {
+      metadata {
+        annotations
+        creationTimestamp
+        labels
+        name
+        namespace
+        resourceVersion
+        uid
+      }
+      raw
+    }
+  }
+`
+
 export const createApplication = gql`
   mutation createApplication($application: [JSON]!) {
     createApplication(application: $application)
@@ -416,6 +476,7 @@ export const HCMTopology = gql`
           uid
         }
       }
+      error
     }
   }
 `
