@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 export const convertStringToQuery = searchText => {
   let relatedKinds = []
@@ -51,3 +52,26 @@ export const formatNumber = count => {
   }
   return count
 }
+
+const MAX_SEARCH_ATTEMPTS = 3
+let searchFailureCount = 0
+let searchErrorCount = 0
+
+export const searchFailure = () => {
+  searchFailureCount++
+  searchErrorCount = 0
+}
+export const searchError = () => {
+  searchErrorCount++
+}
+export const searchSuccess = () => {
+  searchFailureCount = 0
+  searchErrorCount = 0
+}
+
+export const shouldTrySearch = () =>
+  searchFailureCount + searchErrorCount < MAX_SEARCH_ATTEMPTS
+
+export const isSearchAvailable = () =>
+  searchFailureCount === 0 && searchErrorCount === 0
+export const isYAMLEditAvailable = () => searchErrorCount === 0
