@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import React from 'react'
 import msgs from '../../../nls/platform.properties'
@@ -19,6 +20,7 @@ import {
 import ApplicationDeploymentHighlights from '../ApplicationDeploymentHighlights'
 import { withRouter } from 'react-router-dom'
 import AdvancedConfigurationLists from '../AdvancedConfigurationLists'
+import { PageSection, Stack, StackItem } from '@patternfly/react-core'
 
 /* eslint-disable react/prop-types */
 
@@ -63,12 +65,18 @@ class AdvancedConfigurationPage extends React.Component {
     const { secondaryHeaderProps } = this.props
 
     return (
-      <React.Fragment>
-        <ApplicationDeploymentHighlights />
-        <AdvancedConfigurationLists
-          secondaryHeaderProps={secondaryHeaderProps}
-        />
-      </React.Fragment>
+      <PageSection>
+        <Stack hasGutter>
+          <StackItem>
+            <ApplicationDeploymentHighlights />
+          </StackItem>
+          <StackItem>
+            <AdvancedConfigurationLists
+              secondaryHeaderProps={secondaryHeaderProps}
+            />
+          </StackItem>
+        </Stack>
+      </PageSection>
     )
   }
 }
