@@ -1,16 +1,22 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
+
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import { VALIDATE_URL } from 'temptifly'
-import { loadExistingChannels, updateChannelControls } from './utils'
+import {
+  loadExistingChannels,
+  updateChannelControls,
+  channelSimplified
+} from './utils'
 
 import placementData from './ControlDataPlacement'
 
@@ -42,7 +48,17 @@ const helmReleaseChannelData = async () => [
     validation: VALIDATE_URL,
     fetchAvailable: loadExistingChannels('helmrepo'),
     reverse: 'Channel[0].spec.pathname',
-    onSelect: updateChannelControls
+    onSelect: updateChannelControls,
+    simplified: channelSimplified
+  },
+  {
+    name: 'creation.app.helmrepo.secret',
+    tooltip: 'tooltip.creation.app.helmrepo.secret',
+    id: 'helmSecret',
+    type: 'hidden',
+    active: '',
+    available: [],
+    disabled: true
   },
   {
     name: 'creation.app.helmrepo.user',
@@ -99,6 +115,27 @@ const helmReleaseChannelData = async () => [
     placeholder: 'app.enter.helmrepo.package.version',
     reverse: 'Subscription[0].spec.packageFilter.version'
   },
+  {
+    id: 'helmReconcileRate',
+    type: 'combobox',
+    editing: { disabled: true }, // if editing existing app, disable this field
+    name: 'creation.app.reconcileRate',
+    tooltip: 'tooltip.creation.app.reconcileRate',
+    active: 'medium',
+    available: ['low', 'medium', 'high', 'off'],
+    reverse:
+      'Channel[0].metadata.annotations["apps.open-cluster-management.io/reconcile-rate"]'
+  },
+  {
+    id: 'helmSubReconcileRate',
+    type: 'checkbox',
+    name: 'creation.app.subReconcileRate',
+    tooltip: 'tooltip.creation.app.subReconcileRate',
+    active: false,
+    available: [],
+    reverse:
+      'Subscription[0].metadata.annotations["apps.open-cluster-management.io/reconcile-rate"]'
+  },
   {
     id: 'helmInsecureSkipVerify',
     type: 'checkbox',
