@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import cytoscape from 'cytoscape'
@@ -101,7 +102,7 @@ export default class LayoutHelper {
     nodes.forEach(node => {
       if (node.layout) {
         if (this.getNodeTitle) {
-          node.layout.title = this.getNodeTitle(node, this.locale)
+          node.layout.title = this.getNodeTitle(node)
         }
         if (this.getNodeDescription) {
           node.layout.description = this.getNodeDescription(node)
