@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 // seems to be an issue with this rule and redux
 /* eslint-disable import/no-named-as-default */
@@ -13,13 +14,19 @@
 import React from 'react'
 import PropTypes from 'prop-types'
 import { connect } from 'react-redux'
+import {
+  AcmHeader,
+  AcmPage,
+  AcmRoute
+} from '@open-cluster-management/ui-components'
 import SecondaryHeader from '../components/SecondaryHeader'
 import { Route, Switch, Redirect, withRouter } from 'react-router-dom'
 import { withLocale } from '../providers/LocaleProvider'
 import resources from '../../lib/shared/resources'
 import client from '../../lib/shared/client'
-import loadable from 'loadable-components'
+import loadable from '@loadable/component'
 import config from '../../lib/shared/config'
+import _ from 'lodash'
 
 export const ActionModalApollo = loadable(() =>
   import(/* webpackChunkName: "actionModalApollo" */ '../components/common-apollo/ActionModalApollo')
@@ -81,7 +88,7 @@ class App extends React.Component {
 
   render() {
     const serverProps = this.getServerProps()
-    const { locale, match } = this.props
+    const { locale, location, match } = this.props
 
     const BASE_PAGE_PATH = match.url.replace(/\/$/, '')
     const allApplicationsTabs = [
@@ -104,26 +111,30 @@ class App extends React.Component {
     }
 
     const getSingleApplicationTabs = params => {
+      const isArgoApp = _.get(location, 'search').indexOf('argoproj.io') !== -1
       const SINGLE_APP_BASE_PAGE_PATH = getSingleApplicationBasePath(params)
-      return [
+      const overviewTab = [
         {
           id: 'overview',
           label: 'description.title.overview',
           url: SINGLE_APP_BASE_PAGE_PATH
-        },
-        {
+        }
+      ]
+      if (isArgoApp) {
+        return overviewTab
+      } else {
+        return _.concat(overviewTab, {
           id: 'editor',
           label: 'description.title.editor',
           url: `${SINGLE_APP_BASE_PAGE_PATH}/edit`
-        }
-      ]
+        })
+      }
     }
 
     const applicationsTitle = 'routes.applications'
 
     return (
-      <div className="expand-vertically">
-        <SecondaryHeader />
+      <AcmPage header={<SecondaryHeader />}>
         <Switch>
           <Route
             exact
@@ -144,18 +155,16 @@ class App extends React.Component {
             exact
             path={`${BASE_PAGE_PATH}/advanced`}
             render={params => (
-              <div className="page-content-container">
-                <AdvancedConfigurationPage
-                  params={params}
-                  serverProps={serverProps}
-                  secondaryHeaderProps={{
-                    title: applicationsTitle,
-                    tabs: allApplicationsTabs,
-                    mainButton: createApplicationButton
-                  }}
-                  locale={locale}
-                />
-              </div>
+              <AdvancedConfigurationPage
+                params={params}
+                serverProps={serverProps}
+                secondaryHeaderProps={{
+                  title: applicationsTitle,
+                  tabs: allApplicationsTabs,
+                  mainButton: createApplicationButton
+                }}
+                locale={locale}
+              />
             )}
           />
           <Route
@@ -200,19 +209,14 @@ class App extends React.Component {
           <Redirect to={`${config.contextPath}/welcome`} />
         </Switch>
         <ActionModalApollo locale={serverProps.context.locale} />
-        <input
-          type="hidden"
-          id="app-access"
-          style={{ display: 'none' }}
-          value={serverProps.xsrfToken.toString('base64')}
-        />
-      </div>
+      </AcmPage>
     )
   }
 }
 
 App.propTypes = {
   locale: PropTypes.object,
+  location: PropTypes.object,
   match: PropTypes.object,
   serverProps: PropTypes.object,
   staticContext: PropTypes.object
@@ -228,18 +232,31 @@ const mapStateToProps = state => {
   }
 }
 
+const getAcmRoute = props => {
+  let path = ''
+  if (client) {
+    path = window.location.pathname
+  } else {
+    path = props.url
+  }
+  if (path.includes(config.contextPath)) {
+    return AcmRoute.Applications
+  }
+  return AcmRoute.Welcome
+}
+
 const Container = Component =>
   withRouter(withLocale(connect(mapStateToProps)(Component)))
 const AppContainer = Container(App)
 
 const AppComponent = props => (
-  <div className="expand-vertically">
+  <AcmHeader route={getAcmRoute(props)}>
     <Route
       path={config.contextPath}
       serverProps={props}
-      render={() => <AppContainer {...props} />}
+      component={AppContainer}
     />
-  </div>
+  </AcmHeader>
 )
 AppComponent.displayName = 'AppComponent'
 export default AppComponent
