@@ -1,20 +1,24 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import R from 'ramda'
 import {
   createEditLink,
   getAge,
   getEditLink,
   getSearchLink,
-  getClusterCount,
   getClusterCountString
 } from '../../lib/client/resource-helper'
+import {
+  isSearchAvailable,
+  isYAMLEditAvailable
+} from '../../lib/client/search-helper'
 import { cellWidth } from '@patternfly/react-table'
 import { getEmptyMessage } from './hcm-subscription'
 import msgs from '../../nls/platform.properties'
@@ -41,9 +45,10 @@ export default {
     {
       msgKey: 'table.header.clusters',
       resourceKey: 'clusterCount',
-      transformFunction: createClustersLink,
+      transformFunction: createClustersText,
       textFunction: createClustersText,
-      tooltipKey: 'table.header.placementrules.clusters.tooltip'
+      tooltipKey: 'table.header.placementrules.clusters.tooltip',
+      disabled: () => !isSearchAvailable()
     },
     {
       msgKey: 'table.header.replicas',
@@ -56,14 +61,21 @@ export default {
       transformFunction: getAge
     }
   ],
-  tableActions: [
-    {
+  tableActionsResolver: tableActionsResolver
+}
+
+function tableActionsResolver() {
+  const actions = []
+  if (isYAMLEditAvailable()) {
+    actions.push({
       key: 'table.actions.placementrules.edit',
       link: {
         url: getEditLink
       }
-    },
-    {
+    })
+  }
+  if (isSearchAvailable()) {
+    actions.push({
       key: 'table.actions.placementrules.search',
       link: {
         url: item =>
@@ -76,25 +88,14 @@ export default {
             }
           })
       }
-    },
-    {
-      key: 'table.actions.placementrules.remove',
-      modal: true,
-      delete: true
-    }
-  ]
-}
-
-function createClustersLink(item, locale) {
-  const clusterCount = R.path(['clusterCount'], item) || {}
-  return getClusterCount({
-    locale,
-    remoteCount: clusterCount.remoteCount,
-    localPlacement: clusterCount.localCount,
-    name: item.name,
-    namespace: item.namespace,
-    kind: 'placementrule'
+    })
+  }
+  actions.push({
+    key: 'table.actions.placementrules.remove',
+    modal: true,
+    delete: true
   })
+  return actions
 }
 
 function createClustersText(item, locale) {
