@@ -1,17 +1,20 @@
-/** *****************************************************************************
- * Licensed Materials - Property of Red Hat, Inc.
- * Copyright (c) 2020 Red Hat, Inc.
- ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 /* eslint-disable no-console */
-
+const _ = require("lodash");
 const fs = require("fs");
 const path = require("path");
 const util = require("util");
 const rimraf = require("rimraf");
 const { WebClient } = require("@slack/web-api");
 const exec = util.promisify(require("child_process").exec);
-const { SLACK_TOKEN, USER, TRAVIS_BUILD_WEB_URL } = process.env;
+const {
+  BUILD_WEB_URL,
+  GIT_PULL_NUMBER,
+  GIT_REPO_SLUG,
+  SLACK_TOKEN
+} = process.env;
 
 const web = new WebClient(SLACK_TOKEN);
 
@@ -78,9 +81,8 @@ function buildComment(failedTests, prData, slackData) {
   const { id } = slackData;
   return `:failed: *FAILED: ${title}*\n
 ${failedTests.map(test => `- ${test} \n`).join("")}\n
-:travis-ci: <${TRAVIS_BUILD_WEB_URL ||
-    "https://travis-ci.com/github/open-cluster-management/application-ui/pull_requests"}|View build> | :github: <${html_url ||
-    "https://github.com/stolostron/application-ui/pulls"}|View pull request> \n\n
+:cypress: <${BUILD_WEB_URL}|View build> | :github: <${html_url ||
+    "https://github.com/open-cluster-management/application-ui/pulls"}|View pull request> \n\n
 ${id ? `<@${id}>` : ""}`;
 }
 
@@ -96,8 +98,12 @@ function moveVideos(path, videoDir) {
 
 async function mapSlackUserByGitEmail() {
   try {
+    const { stdout } = await exec(
+      `curl https://api.github.com/repos/${GIT_REPO_SLUG}/pulls/${GIT_PULL_NUMBER}/commits`
+    );
+    const userEmail = _.get(JSON.parse(stdout)[0], "commit.author.email", "");
     const { user: { id } } = await web.users.lookupByEmail({
-      email: USER
+      email: userEmail
     });
     return { id };
   } catch (e) {
@@ -115,7 +121,7 @@ async function postVideo(fileName, filePath, comment, userId) {
       initial_comment: comment
     });
   } catch (e) {
-    console.error("Slack Post Error", e);
+    console.log("Slack Post Error", e);
   }
 }
 
@@ -139,10 +145,9 @@ function getTestFailureData(report) {
 }
 
 async function getPullRequestData() {
-  const { GITHUB_TOKEN, TRAVIS_REPO_SLUG, TRAVIS_PULL_REQUEST } = process.env;
   try {
     const { stdout } = await exec(
-      `curl -H "Authorization: token ${GITHUB_TOKEN}" https://api.github.com/repos/${TRAVIS_REPO_SLUG}/pulls/${TRAVIS_PULL_REQUEST}`
+      `curl https://api.github.com/repos/${GIT_REPO_SLUG}/pulls/${GIT_PULL_NUMBER}`
     );
     return JSON.parse(stdout);
   } catch (e) {
