@@ -1,18 +1,18 @@
-/** *****************************************************************************
- * Licensed Materials - Property of Red Hat, Inc.
- * Copyright (c) 2020 Red Hat, Inc.
- ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 /// <reference types="cypress" />
 import {
   pageLoader,
   resourceTable,
   modal,
+  notification,
   noResource,
   indexedCSS,
   validateSubscriptionTable,
   getSingleAppClusterTimeDetails,
   getNamespace,
+  getArgoGroupKey,
   getResourceKey,
   verifyApplicationData,
   validateSubscriptionDetails,
@@ -21,7 +21,8 @@ import {
   validateDeployables,
   validateRbacAlert,
   selectClusterDeployment,
-  verifyYamlTemplate
+  verifyYamlTemplate,
+  validateSyncFunction
 } from "./common";
 
 import { channelsInformation, checkExistingUrls } from "./resources.js";
@@ -38,9 +39,9 @@ export const createApplication = (
   const { name, config } = data;
   namespace == "default" ? (namespace = `${name}-ns`) : namespace;
   cy.log(`Test create application ${name}`);
-  cy.get(".bx--detail-page-header-title-container").should("exist");
-  cy.get("#name", { timeout: 50 * 1000 }).type(name);
-  cy.get("#namespace", { timeout: 50 * 1000 }).type(namespace);
+  cy.get(".pf-c-title").should("exist");
+  cy.get("#eman", { timeout: 50 * 1000 }).type(name);
+  cy.get("#emanspace", { timeout: 50 * 1000 }).type(namespace);
   if (type === "git") {
     createGit(clusterName, config);
   } else if (type === "objectstore") {
@@ -48,7 +49,7 @@ export const createApplication = (
   } else if (type === "helm") {
     createHelm(clusterName, config);
   }
-  submitSave(true);
+  submitSave(true, name);
 };
 
 export const gitTasks = (clusterName, value, gitCss, key = 0) => {
@@ -58,9 +59,13 @@ export const gitTasks = (clusterName, value, gitCss, key = 0) => {
     token,
     branch,
     path,
+    commitHash,
+    tag,
     timeWindow,
     deployment,
     gitReconcileOption,
+    repositoryReconcileRate,
+    disableAutoReconcileOption,
     insecureSkipVerifyOption
   } = value;
   cy.log(`gitTasks key=${key}, url=${url}, path=${path}`);
@@ -70,53 +75,71 @@ export const gitTasks = (clusterName, value, gitCss, key = 0) => {
     gitKey,
     gitBranch,
     gitPath,
+    gitCommitHash,
+    gitTag,
     merge,
+    reconcileRate,
+    disableAutoReconcile,
     insecureSkipVerify
   } = gitCss;
 
   cy
     .get(`#git`)
+    .last()
     .scrollIntoView()
     .click()
     .trigger("mouseover");
 
-  cy
-    .get(gitUrl, { timeout: 20 * 1000 })
-    .type(url, { timeout: 50 * 1000 })
-    .blur();
-  checkExistingUrls(gitUser, username, gitKey, token, url);
+  checkExistingUrls(gitUser, username, gitKey, token, gitUrl, url);
 
   if (insecureSkipVerifyOption) {
     cy.get(insecureSkipVerify).click({ force: true });
   }
   // type in branch and path
   cy.get(".bx—inline.loading", { timeout: 30 * 1000 }).should("not.exist");
-  if (url.indexOf("github.com") >= 0) {
-    cy.get(gitBranch, { timeout: 50 * 1000 }).click();
-    cy.contains(".bx--list-box__menu-item", new RegExp(`^${branch}$`)).click();
-  } else {
-    cy
-      .get(gitBranch, { timeout: 50 * 1000 })
-      .type(branch, { timeout: 50 * 1000 })
-      .blur();
-  }
+  //type in branch name here instead of trying to select one
+  // the git api is unreliable and we don't want to fail all git app tests
+  //if the branch doesn't show up
+  cy
+    .get(gitBranch, { timeout: 50 * 1000 })
+    .type(branch, { timeout: 50 * 1000 })
+    .blur();
+
   cy.wait(1000);
   cy.get(".bx—inline.loading", { timeout: 30 * 1000 }).should("not.exist");
-  if (url.indexOf("github.com") >= 0) {
-    cy.get(gitPath, { timeout: 20 * 1000 }).click();
-    cy.contains(".bx--list-box__menu-item", new RegExp(`^${path}$`)).click();
-  } else {
+  //type in folder name here instead of trying to select one, same reason as above, for branch
+  cy
+    .get(gitPath, { timeout: 20 * 1000 })
+    .type(path, { timeout: 30 * 1000 })
+    .blur();
+
+  commitHash &&
     cy
-      .get(gitPath, { timeout: 20 * 1000 })
-      .type(path, { timeout: 30 * 1000 })
+      .get(gitCommitHash, { timeout: 20 * 1000 })
+      .type(commitHash, { timeout: 30 * 1000 })
       .blur();
-  }
+
+  tag &&
+    cy
+      .get(gitTag, { timeout: 20 * 1000 })
+      .type(tag, { timeout: 30 * 1000 })
+      .blur();
+
   if (gitReconcileOption) {
     cy
       .get(merge)
       .type(gitReconcileOption)
       .blur();
   }
+  if (repositoryReconcileRate) {
+    cy
+      .get(reconcileRate)
+      .clear({ force: true })
+      .type(repositoryReconcileRate, { force: true });
+  }
+  if (disableAutoReconcileOption) {
+    cy.get(disableAutoReconcile).click({ force: true });
+  }
   selectPrePostTasks(value, key);
   selectClusterDeployment(deployment, clusterName, key);
   selectTimeWindow(timeWindow, key);
@@ -128,8 +151,11 @@ export const createHelm = (clusterName, configs, addOperation) => {
     helmUsername: "#helmUser",
     helmPassword: "#helmPassword",
     helmChartName: "#helmChartName",
+    helmPackageAlias: "#helmPackageAlias",
     helmPackageVersion: "#helmPackageVersion",
-    insecureSkipVerify: "#helmInsecureSkipVerify"
+    insecureSkipVerify: "#helmInsecureSkipVerify",
+    reconcileRate: "#helmReconcileRate",
+    disableAutoReconcile: "#helmSubReconcileRate"
   };
   if (addOperation) {
     //add new subscription to existing app
@@ -158,28 +184,39 @@ export const helmTasks = (clusterName, value, css, key = 0) => {
     username,
     password,
     chartName,
+    packageAlias,
     packageVersion,
     timeWindow,
     deployment,
-    insecureSkipVerifyOption
+    insecureSkipVerifyOption,
+    repositoryReconcileRate,
+    disableAutoReconcileOption
   } = value;
   const {
     helmURL,
     helmUsername,
     helmPassword,
     helmChartName,
+    helmPackageAlias,
     helmPackageVersion,
-    insecureSkipVerify
+    insecureSkipVerify,
+    reconcileRate,
+    disableAutoReconcile
   } = css;
   cy
     .get("#helm")
+    .last()
     .click()
     .trigger("mouseover");
-  cy
-    .get(helmURL, { timeout: 20 * 1000 })
-    .type(url, { timeout: 30 * 1000 })
-    .blur();
-  checkExistingUrls(helmUsername, username, helmPassword, password, url);
+
+  checkExistingUrls(
+    helmUsername,
+    username,
+    helmPassword,
+    password,
+    helmURL,
+    url
+  );
 
   if (insecureSkipVerifyOption) {
     cy.get(insecureSkipVerify).click({ force: true });
@@ -188,11 +225,26 @@ export const helmTasks = (clusterName, value, css, key = 0) => {
     .get(helmChartName, { timeout: 20 * 1000 })
     .type(chartName)
     .blur();
+  packageAlias && cy.get(helmPackageAlias, { timeout: 20 * 1000 }).clear();
+  packageAlias &&
+    cy
+      .get(helmPackageAlias, { timeout: 20 * 1000 })
+      .type(packageAlias)
+      .blur();
+
   packageVersion &&
     cy
       .get(helmPackageVersion, { timeout: 20 * 1000 })
       .type(packageVersion)
       .blur();
+
+  if (repositoryReconcileRate) {
+    cy.get(reconcileRate).type(repositoryReconcileRate, { force: true });
+  }
+  if (disableAutoReconcileOption) {
+    cy.get(disableAutoReconcile).click({ force: true });
+  }
+
   selectClusterDeployment(deployment, clusterName, key);
   selectTimeWindow(timeWindow, key);
 };
@@ -204,7 +256,11 @@ export const createGit = (clusterName, configs, addOperation) => {
     gitKey: "#githubAccessId",
     gitBranch: "#githubBranch",
     gitPath: "#githubPath",
+    gitCommitHash: "#gitDesiredCommit",
+    gitTag: "#gitTag",
     merge: "#gitReconcileOption",
+    reconcileRate: "#gitReconcileRate",
+    disableAutoReconcile: "#gitSubReconcileRate",
     insecureSkipVerify: "#gitInsecureSkipVerify"
   };
   if (addOperation) {
@@ -261,15 +317,17 @@ export const objTasks = (clusterName, value, css, key = 0) => {
   const { objUrl, objAccess, objSecret } = css;
   cy
     .get("#object-storage")
+    .last()
     .click()
     .trigger("mouseover");
-  cy.get(objUrl, { timeout: 20 * 1000 }).type(url, { timeout: 30 * 1000 });
-  checkExistingUrls(objAccess, accessKey, objSecret, secretKey, url);
+
+  checkExistingUrls(objAccess, accessKey, objSecret, secretKey, objUrl, url);
   selectClusterDeployment(deployment, clusterName, key);
   selectTimeWindow(timeWindow, key);
 };
 
 export const multipleTemplate = (clusterName, value, css, key, func) => {
+  cy.wait(1000);
   cy.get("#add-channels").click({ force: true });
   cy
     .get(".creation-view-group-container")
@@ -309,6 +367,13 @@ export const validateAdvancedTables = (
         } else {
           cy.log(`Validating ${tableType} on Advanced Tables`);
           cy.visit(`/multicloud/applications/advanced?resource=${tableType}`);
+
+          //search is not properly scrolled to view; attempt to move it lower on the page
+          //by asking the terminology to show
+          cy
+            .get("#ApplicationDeploymentHighlightsTerminology")
+            .scrollIntoView();
+
           resourceTable.rowShouldExist(
             resourceTypes[tableType],
             getResourceKey(
@@ -332,6 +397,22 @@ export const validateAdvancedTables = (
   }
 };
 
+export const verifyDetails = (name, namespace, apiVersion) => {
+  cy.visit(
+    `/multicloud/applications/${namespace}/${name}${
+      apiVersion ? apiVersion : ""
+    }`
+  );
+  cy.reload();
+  cy
+    .get(".search-query-card-loading", { timeout: 50 * 1000 })
+    .should("not.exist");
+  cy
+    .get(".pf-l-grid__item")
+    .first()
+    .contains(name);
+};
+
 /*
 opType = 'create' if run afer app creation step
 opType = 'delete' if run afer delete subs step
@@ -343,21 +424,17 @@ export const validateTopology = (
   type,
   clusterName,
   numberOfRemoteClusters,
-  opType
+  opType,
+  namespace
 ) => {
-  cy.visit(`/multicloud/applications/${name}-ns/${name}`);
-  cy.reload();
-  cy
-    .get(".search-query-card-loading", { timeout: 50 * 1000 })
-    .should("not.exist");
-  cy
-    .get(".pf-l-grid__item")
-    .first()
-    .contains(name);
-  cy
-    .get(".pf-l-grid__item")
-    .first()
-    .contains(`${name}-ns`);
+  const apiVersion = `?apiVersion=${
+    type === "argo" ? "argoproj.io/v1alpha1" : "app.k8s.io%2Fv1beta1"
+  }`;
+  if (!namespace) {
+    namespace = `${name}-ns`;
+  }
+
+  verifyDetails(name, namespace, apiVersion);
 
   const appDetails = getSingleAppClusterTimeDetails(
     data,
@@ -368,14 +445,21 @@ export const validateTopology = (
     `Verify cluster deploy status on app card is ${appDetails.clusterData}`
   );
 
+  // verify search resource
   cy
-    .get("#app-search-link")
+    .get("#app-search-link", { timeout: 20 * 1000 })
     .invoke("attr", "href")
     .should(
       "include",
-      `search?filters={"textsearch":"kind%3Aapplication%20name%3A${name}%20namespace%3A${name}-ns"}`
+      `search?filters={"textsearch":"kind%3Aapplication%20name%3A${name}%20namespace%3A${namespace}`
     );
 
+  if (type === "argo") {
+    validateArgoLinks(data.config);
+  }
+
+  validateSyncFunction(type, opType);
+
   validateSubscriptionDetails(name, data, type, opType);
 
   cy.get(".overview-cards-container");
@@ -388,12 +472,17 @@ export const validateTopology = (
   cy.log("validate the application...");
   cy.get(`g[type=${name}]`, { timeout: 25 * 1000 }).should("be.visible");
 
-  //subscription
-  cy.log("validate the subscription...");
-  const subsIndex = opType == "create" ? 1 : 2; //add new subs or delete subs
-  cy
-    .get(`g[type="${name}-subscription-${subsIndex}"]`, { timeout: 25 * 1000 })
-    .should("be.visible");
+  if (type !== "argo") {
+    //subscription
+    cy.log("validate the subscription...");
+    const subsIndex = opType == "create" ? 1 : 2; //add new subs or delete subs
+    cy
+      .get(`g[type="${name}-subscription-${subsIndex}"]`, {
+        timeout: 25 * 1000
+      })
+      .scrollIntoView()
+      .should("be.visible");
+  }
 
   // cluster and placement
   for (const [key, value] of Object.entries(data.config)) {
@@ -401,11 +490,11 @@ export const validateTopology = (
     if (opType !== "delete") {
       if (data.config.length > 1 || opType == "add") {
         cy.get(".channelsCombo", { timeout: 60 * 1000 }).within($channels => {
-          cy.get(".bx--list-box__field", { timeout: 20 * 1000 }).click();
+          cy.get(".pf-c-dropdown__toggle", { timeout: 20 * 1000 }).click();
           //select all subscriptions
           cy
-            .get(".bx--list-box__menu-item", { timeout: 20 * 1000 })
-            .first()
+            .get(".pf-c-dropdown__menu>li", { timeout: 20 * 1000 })
+            .eq(0)
             .click();
         });
 
@@ -421,22 +510,6 @@ export const validateTopology = (
     } else {
       //if opType is create, the first subscription was removed by the delete subs test, use the new config option
       validateDeployables(opType == "add" ? data.new[0] : value);
-
-      const { local, online } =
-        key == 0 && opType == "add" ? data.new[0].deployment : value.deployment;
-      cy.log(`key=${key}, type=${opType}`);
-      if (!local) {
-        if (opType !== "add") {
-          validatePlacementNode(name, key);
-        }
-        if (!online) {
-          validateClusterNode(clusterName); //ignore online placements since the app is deployed on all online clusters here and we don't know for sure how many remote clusters the hub has
-        }
-      } else {
-        cy.log(
-          "cluster and placement nodes will not be created as the application is deployed locally"
-        );
-      }
     }
   }
 
@@ -461,16 +534,6 @@ export const validateTopology = (
   }
 };
 
-export const validateClusterNode = clusterName => {
-  cy.log(`validating the cluster... ${clusterName}`);
-  if (clusterName == "local-cluster") {
-    // only check local-cluster due to issue #9557
-    cy
-      .get(`g[type="${clusterName}"]`, { timeout: 25 * 1000 })
-      .should("be.visible");
-  }
-};
-
 export const validatePlacementNode = (name, key) => {
   cy.log("validate the placementrule..."),
     cy
@@ -480,6 +543,18 @@ export const validatePlacementNode = (name, key) => {
       .should("be.visible");
 };
 
+export const validateArgoLinks = config => {
+  const { path } = config[0];
+  // search all related applications
+  cy
+    .get("#app-search-argo-apps-link", { timeout: 20 * 1000 })
+    .invoke("attr", "href")
+    .should("include", path);
+
+  // should get element launch argocd editor
+  cy.get("#launch-argocd-editor", { timeout: 20 * 1000 });
+};
+
 export const validateAppTableMenu = (name, resourceTable) => {
   //validate SEARCH menu
 
@@ -487,8 +562,8 @@ export const validateAppTableMenu = (name, resourceTable) => {
     // check popup actions on one app only, that's sufficient
     return;
   }
-  const resourceKey = getResourceKey(name, getNamespace(name));
-  resourceTable.openRowMenu(name, getResourceKey(name, getNamespace(name)));
+  const resourceKey = getResourceKey(name, getNamespace(name), "local-cluster");
+  resourceTable.openRowMenu(name, resourceKey);
   resourceTable.menuClick("search");
   cy
     .url()
@@ -509,9 +584,7 @@ export const validateAppTableMenu = (name, resourceTable) => {
   //validate Edit menu
   resourceTable.openRowMenu(name, resourceKey);
   resourceTable.menuClick("edit");
-  cy.get(".bx--detail-page-header-title").should("exist", {
-    timeout: 60 * 1000
-  });
+
   //get back to app page
   cy.visit(`/multicloud/applications`);
   cy.get(".search-query-card-loading").should("not.exist", {
@@ -529,28 +602,52 @@ export const validateAppTableMenu = (name, resourceTable) => {
   });
 };
 
-export const validateResourceTable = (name, data, numberOfRemoteClusters) => {
+export const validateResourceTable = (
+  name,
+  data,
+  type,
+  numberOfRemoteClusters,
+  namespace,
+  deployedNamespace
+) => {
+  if (!namespace) {
+    namespace = getNamespace(name);
+  }
   cy.visit(`/multicloud/applications`);
   cy.get(".search-query-card-loading").should("not.exist", {
     timeout: 60 * 1000
   });
   pageLoader.shouldNotExist();
-  const resourceKey = getResourceKey(name, getNamespace(name));
+  const groupKey =
+    type === "argo"
+      ? getArgoGroupKey(name, namespace, "local-cluster", data)
+      : null;
+  const resourceKey = getResourceKey(name, namespace, "local-cluster");
   resourceTable.rowShouldExist(name, resourceKey, 60 * 1000);
 
   //validate content
-  resourceTable.getRow(name, resourceKey).within(() =>
+  resourceTable.getRow(name, groupKey || resourceKey).within(() =>
     resourceTable
       .getCell("Name")
       .invoke("text")
-      .should("eq", name)
+      .should("include", name)
   );
 
+  if (type === "argo") {
+    // validate that argo icon exists
+    resourceTable.getRow(type, groupKey || resourceKey).within(() =>
+      resourceTable
+        .getCell("Name")
+        .invoke("text")
+        .should("include", type)
+    );
+    cy.get("#expandable-toggle0").click();
+  }
   resourceTable.getRow(name, resourceKey).within(() =>
     resourceTable
-      .getCell("Namespace")
+      .getCell("Namespace", type === "argo" ? 2 : null)
       .invoke("text")
-      .should("eq", `${name}-ns`)
+      .should("include", type === "argo" ? deployedNamespace : namespace)
   );
 
   const appDetails = getSingleAppClusterTimeDetails(
@@ -558,8 +655,9 @@ export const validateResourceTable = (name, data, numberOfRemoteClusters) => {
     numberOfRemoteClusters,
     "create"
   );
+
   cy.log("Validate Cluster column");
-  resourceTable.getRow(name, resourceKey).within(() =>
+  resourceTable.getRow(name, groupKey || resourceKey).within(() =>
     resourceTable
       .getCell("Clusters")
       .invoke("text")
@@ -576,7 +674,7 @@ export const validateResourceTable = (name, data, numberOfRemoteClusters) => {
       ? `${repositoryText} (${subscriptionLength})`
       : repositoryText;
   cy.log("Validate Repository column");
-  resourceTable.getRow(name, resourceKey).within(() =>
+  resourceTable.getRow(name, groupKey || resourceKey).within(() =>
     resourceTable
       .getCell("Resource")
       .invoke("text")
@@ -584,7 +682,7 @@ export const validateResourceTable = (name, data, numberOfRemoteClusters) => {
   );
 
   cy.log("Validate Repository popup");
-  resourceTable.getRow(name, resourceKey).within(() =>
+  resourceTable.getRow(name, groupKey || resourceKey).within(() =>
     resourceTable
       .getCell("Resource")
       .find(".pf-c-label")
@@ -607,7 +705,7 @@ export const validateResourceTable = (name, data, numberOfRemoteClusters) => {
   });
 
   cy.log("Validate Window column");
-  resourceTable.getRow(name, resourceKey).within(() =>
+  resourceTable.getRow(name, groupKey || resourceKey).within(() =>
     resourceTable
       .getCell("Time window")
       .invoke("text")
@@ -641,10 +739,13 @@ export const deleteResourceUI = (name, type) => {
 
   resourceTable.openRowMenu(resourceTypes[type], resourceKey);
   resourceTable.menuClick("delete");
-  modal.shouldBeOpen();
+  modal.shouldBeOpen("#remove-resource-modal");
   cy.get(".pf-c-empty-state", { timeout: 100 * 1000 }).should("not.exist");
   modal.clickDanger();
-  modal.shouldBeClosed();
+  modal.shouldBeClosed("#remove-resource-modal");
+
+  // verify success alert
+  notification.shouldExist("success");
 
   // after deleting the app, it should not exist in the app table
   resourceTable.rowShouldNotExist(
@@ -659,12 +760,12 @@ export const deleteApplicationUI = (name, namespace = "default") => {
   namespace == "default" ? (namespace = getNamespace(name)) : namespace;
   cy.visit("/multicloud/applications");
   if (noResource.shouldNotExist()) {
-    const resourceKey = getResourceKey(name, namespace);
+    const resourceKey = getResourceKey(name, namespace, "local-cluster");
     resourceTable.rowShouldExist(name, resourceKey, 30 * 1000);
 
     resourceTable.openRowMenu(name, resourceKey);
     resourceTable.menuClick("delete");
-    modal.shouldBeOpen();
+    modal.shouldBeOpen("#remove-resource-modal");
 
     cy.get(".pf-c-empty-state", { timeout: 50 * 1000 }).should("not.exist", {
       timeout: 20 * 1000
@@ -677,7 +778,7 @@ export const deleteApplicationUI = (name, namespace = "default") => {
     }
     modal.clickDanger();
     // after deleting the app, it should not exist in the app table
-    modal.shouldBeClosed();
+    modal.shouldBeClosed("#remove-resource-modal");
     resourceTable.rowShouldNotExist(name, resourceKey, 30 * 1000, true);
   } else {
     cy.log("No apps to delete...");
@@ -693,52 +794,34 @@ export const deleteApplicationUI = (name, namespace = "default") => {
 };
 
 export const selectPrePostTasks = (value, key) => {
-  const { ansibleSecretName, ansibleHost, ansibleToken } = value;
-  if (!ansibleSecretName) {
+  const { ansibleSecretName } = value;
+  // get the name of the ansible secret from secret config
+  const { name } = Cypress.env("SECRET_CONFIG").metadata;
+  if (ansibleSecretName && ansibleSecretName == name) {
+    key == 0
+      ? (cy
+          .get("#perpostsection-configure-automation-for-prehook-and-posthook")
+          .click(),
+        cy
+          .get("#ansibleSecretName-label", { timeout: 20 * 1000 })
+          .click()
+          .type(name))
+      : (cy
+          .get(`#perpostsectiongrp${key}-set-pre-and-post-deployment-tasks`)
+          .click(),
+        cy
+          .get(`#ansibleSecretName${key}-label`, { timeout: 20 * 1000 })
+          .click()
+          .type(name));
+    cy.wait(1000);
+    cy
+      .get(".pf-c-select__menu")
+      .first()
+      .scrollIntoView()
+      .click();
+  } else {
     cy.log("PrePost SecretName not available, ignore this section");
-    return;
   }
-  let prePostCss = {
-    gitAnsibleSecret: "#ansibleSecretName",
-    gitAnsibleHost: "#ansibleTowerHost",
-    gitAnsibleToken: "#ansibleTowerToken"
-  };
-  key == 0
-    ? prePostCss
-    : Object.keys(prePostCss).forEach(k => {
-        prePostCss[k] = prePostCss[k] + `grp${key}`;
-      });
-  const { gitAnsibleSecret, gitAnsibleHost, gitAnsibleToken } = prePostCss;
-
-  key == 0
-    ? cy.get("#perpostsection-set-pre-and-post-deployment-tasks").click()
-    : cy
-        .get(`#perpostsectiongrp${key}-set-pre-and-post-deployment-tasks`)
-        .click();
-
-  cy.get(gitAnsibleSecret, { timeout: 20 * 1000 }).click();
-
-  cy.get(".bx--list-box__menu", { timeout: 20 * 1000 }).then($listbox => {
-    if ($listbox.find(".bx--list-box__menu-item").length) {
-      // Ansible secret alraedy exists in this namespace
-      cy.contains(".bx--list-box__menu-item", ansibleSecretName).click();
-    } else {
-      // Create new ansible secret in this namespace
-      cy
-        .get(gitAnsibleSecret, { timeout: 20 * 1000 })
-        .type(ansibleSecretName, { timeout: 50 * 1000 })
-        .blur();
-
-      if (ansibleHost && ansibleToken) {
-        cy
-          .get(gitAnsibleHost, { timeout: 20 * 1000 })
-          .paste(ansibleHost, { log: false, timeout: 20 * 1000 });
-        cy
-          .get(gitAnsibleToken, { timeout: 20 * 1000 })
-          .paste(ansibleToken, { log: false, timeout: 20 * 1000 });
-      }
-    }
-  });
 };
 
 export const edit = (name, namespace = "default") => {
@@ -750,7 +833,7 @@ export const edit = (name, namespace = "default") => {
     })
     .as("graphql");
   cy.visit("/multicloud/applications");
-  const resourceKey = getResourceKey(name, namespace);
+  const resourceKey = getResourceKey(name, namespace, "local-cluster");
   resourceTable.rowShouldExist(name, resourceKey, 30 * 1000);
   resourceTable.openRowMenu(name, resourceKey);
   resourceTable.menuClick("edit");
@@ -765,18 +848,16 @@ export const edit = (name, namespace = "default") => {
 export const editApplication = (name, data) => {
   edit(name);
   cy.log("Verify name and namespace fields are disabled");
-  cy.get(".bx--detail-page-header-title-container", { timeout: 20 * 1000 });
+  cy.get(".pf-c-title", { timeout: 20 * 1000 });
   cy.get(".creation-view-yaml", { timeout: 20 * 1000 });
+  cy.get("#eman", { timeout: 20 * 1000 }).should("be.disabled");
   cy
-    .get(".bx--text-input.bx--text__input", { timeout: 20 * 1000 })
-    .should("be.disabled");
-  cy
-    .get(".bx--text-input.bx--text__input", { timeout: 20 * 1000 })
+    .get("#eman", { timeout: 20 * 1000 })
     .invoke("val")
     .should("eq", name);
-  cy.get("#namespace", { timeout: 20 * 1000 }).should("be.disabled");
+  cy.get("#emanspace", { timeout: 20 * 1000 }).should("be.disabled");
   cy
-    .get("#namespace", { timeout: 20 * 1000 })
+    .get("#emanspace", { timeout: 20 * 1000 })
     .invoke("val")
     .should("eq", `${name}-ns`);
   cy.log("Verify Update button is disabled");
@@ -796,17 +877,23 @@ export const deleteFirstSubscription = (name, data, namespace = "default") => {
     );
 
     cy.get(".creation-view-controls-section").within($section => {
+      cy.wait(1000);
       cy
         .get(".creation-view-group-container")
         .first()
         .within($div => {
-          cy.get(".creation-view-controls-delete-button").click();
+          cy
+            .get(".creation-view-controls-delete-button")
+            .scrollIntoView()
+            .click();
         });
     });
     cy.log(
       `verify subscription can no longer be deleted for ${name} since there is only one subscription left`
     );
-    cy.get(".creation-view-controls-delete-button").should("not.exist");
+    cy
+      .get(".creation-view-controls-delete-button", { timeout: 20 * 1000 })
+      .should("not.exist");
     submitSave(true);
 
     //verify channel combo doesn't show up
@@ -901,7 +988,7 @@ export const verifyInsecureSkipAfterNewSubscription = name => {
 
 export const verifyUnauthorizedApplicationDelete = (name, namespace) => {
   cy.visit("/multicloud/applications");
-  const resourceKey = getResourceKey(name, namespace);
+  const resourceKey = getResourceKey(name, namespace, "local-cluster");
   resourceTable.rowShouldExist(name, resourceKey, 30 * 1000);
   resourceTable.openRowMenu(name, resourceKey);
   resourceTable.menuClick("delete");
@@ -910,6 +997,6 @@ export const verifyUnauthorizedApplicationDelete = (name, namespace) => {
     .get("[data-ouia-component-id=OUIA-Generated-Button-danger-1]", {
       timeout: 20 * 1000
     })
-    .contains("Delete application")
+    .contains("Delete")
     .should("be.disabled");
 };
