@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2016, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 jest.mock("../../../lib/client/apollo-client", () => ({
   getClient: jest.fn(() => {
@@ -20,6 +21,7 @@ jest.mock("../../../lib/client/apollo-client", () => ({
             _uid: "local-cluster/5cd1d4c7-52aa-11ea-bf05-00000a102d26",
             name: "mortgage-app",
             namespace: "default",
+            cluster: "local-cluster",
             dashboard:
               "https://localhost:443/grafana/dashboard/db/mortgage-app-dashboard-via-federated-prometheus?namespace=default",
             clusterCount: 1,
@@ -143,7 +145,7 @@ describe("ApplicationsListPage", () => {
       .simulate("click");
     // clear search
     tree
-      .find('button[aria-label="Clear"]')
+      .find('button[aria-label="Reset"]')
       .at(0)
       .simulate("click");
   });
