@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 "use strict";
 
@@ -32,7 +33,6 @@ import {
   getGitBranches,
   updateNewRuleControlsData,
   updateChannelControls,
-  updatePrePostControls,
   setAvailableSecrets,
   getUniqueChannelName
 } from "../../../../../src-web/components/ApplicationCreationPage/controlData/utils";
@@ -209,93 +209,31 @@ describe("updateChannelControls", () => {
   });
 });
 
-describe("updatePrePostControls", () => {
-  const data = {
-    active: "secretName",
-    availableData: [],
-    groupControlData: [
-      {
-        id: "ansibleTowerHost",
-        type: "hidden",
-        active: ""
-      },
-      {
-        id: "ansibleTowerToken",
-        type: "hidden",
-        active: ""
-      }
-    ]
-  };
-
-  const result = {
-    active: "secretName",
-    availableData: [],
-    groupControlData: [
-      { active: "", id: "ansibleTowerHost", type: "text" },
-      { active: "", id: "ansibleTowerToken", type: "password" }
-    ]
-  };
-  it("updatePrePostControls new secret", () => {
-    expect(updatePrePostControls(data, controlDataNS)).toEqual(result);
-  });
-});
-
-describe("updatePrePostControls", () => {
-  const data = {
-    active: "secretName",
-    availableData: { secretName: {} },
-    groupControlData: [
-      {
-        id: "ansibleTowerHost",
-        type: "hidden",
-        active: ""
-      },
-      {
-        id: "ansibleTowerToken",
-        type: "hidden",
-        active: ""
-      }
-    ]
-  };
-
-  const result = {
-    active: "secretName",
-    availableData: { secretName: {} },
-    groupControlData: [
-      { active: "", id: "ansibleTowerHost", type: "hidden" },
-      { active: "", id: "ansibleTowerToken", type: "hidden" }
-    ]
-  };
-  it("updatePrePostControls existing secret", () => {
-    expect(updatePrePostControls(data, controlDataNS)).toEqual(result);
-  });
-});
-
 describe("validateBranch", () => {
   const validGitBranches = [
-    "master",
+    "main",
     "release-2.1",
-    "master/resource/abc",
-    "master@abc"
+    "main/resource/abc",
+    "main@abc"
   ];
   const invalidGitBranches = [
     "foo/bar.lock/hello",
-    "master..123",
-    "master.",
-    "master/.abc",
-    "/master",
-    "master/",
-    "master/.lock",
-    "master:12",
+    "main..123",
+    "main.",
+    "main/.abc",
+    "/main",
+    "main/",
+    "main/.lock",
+    "main:12",
     "abc~",
-    "master:",
+    "main:",
     "abc?a",
     "abc*a",
     "abc[a",
-    "master@{",
-    "master.",
+    "main@{",
+    "main.",
     "abc//efg",
-    "master^",
+    "main^",
     "@"
   ];
 
@@ -429,22 +367,84 @@ describe("setAvailableChannelSpecs", () => {
           type: "git",
           metadata: {
             name: "aa-ns"
-          }
+          },
+          objectPath: "https://github.com/fxiang1/app-samples.git"
         }
       ]
     }
   };
   const result = {
-    active: true,
-    available: ["undefined"],
-    availableData: { undefined: { metadata: { name: "aa-ns" }, type: "git" } },
-    availableMap: {},
     id: "channel",
+    active: true,
+    availableData: {
+      "https://github.com/fxiang1/app-samples.git [ns/aa-ns]": {
+        type: "git",
+        metadata: { name: "aa-ns" },
+        objectPath: "https://github.com/fxiang1/app-samples.git"
+      }
+    },
+    available: ["https://github.com/fxiang1/app-samples.git [ns/aa-ns]"],
+    availableMap: {},
     isLoading: false
   };
   it("setAvailableChannelSpecs no error", () => {
     expect(setAvailableChannelSpecs(type, urlControl, model)).toEqual(result);
   });
+  const helmModel = {
+    data: {
+      items: [
+        {
+          type: "helm",
+          metadata: {
+            name: "aa-ns-1"
+          },
+          objectPath:
+            "http://multiclusterhub-repo.open-cluster-management.svc.cluster.local:3000/charts"
+        },
+        {
+          type: "helm",
+          metadata: {
+            name: "aa-ns-2"
+          },
+          objectPath: "https://charts.bitnami.com/bitnami"
+        },
+        {
+          type: "helm",
+          metadata: {
+            name: "aa-ns-3"
+          },
+          objectPath: ""
+        }
+      ]
+    }
+  };
+  const helmResult = {
+    id: "channel",
+    active: true,
+    availableData: {
+      "https://charts.bitnami.com/bitnami [ns/aa-ns-2]": {
+        type: "helm",
+        metadata: { name: "aa-ns-2" },
+        objectPath: "https://charts.bitnami.com/bitnami"
+      },
+      " [ns/aa-ns-3]": {
+        type: "helm",
+        metadata: { name: "aa-ns-3" },
+        objectPath: ""
+      }
+    },
+    available: [
+      " [ns/aa-ns-3]",
+      "https://charts.bitnami.com/bitnami [ns/aa-ns-2]"
+    ],
+    availableMap: {},
+    isLoading: false
+  };
+  it("setAvailableChannelSpecs exclude MCH helm repo", () => {
+    expect(setAvailableChannelSpecs("helm", urlControl, helmModel)).toEqual(
+      helmResult
+    );
+  });
 });
 
 describe("setAvailableChannelSpecs", () => {
@@ -548,7 +548,16 @@ describe("setAvailableSecrets", () => {
     active: true,
     available: ["undefined"],
     availableData: { undefined: { metadata: { name: "aa-ns" } } },
-    availableMap: {},
+    availableMap: {
+      undefined: {
+        replacements: {
+          metadata: {
+            name: "aa-ns"
+          }
+        }
+      }
+    },
+    hasReplacements: true,
     id: "namespace",
     isLoading: false
   };
@@ -572,7 +581,7 @@ describe("setAvailableSecrets", () => {
     active: true,
     available: [],
     availableData: {},
-    availableMap: {},
+    hasReplacements: true,
     id: "namespace",
     isFailed: true,
     isLoading: false
@@ -596,7 +605,7 @@ describe("setAvailableSecrets", () => {
     active: true,
     available: [],
     availableData: {},
-    availableMap: {},
+    hasReplacements: true,
     id: "namespace",
     isLoading: "loading message"
   };
