@@ -1,6 +1,5 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 "use strict";
 
 import { getLegendTitle } from "../../../../../../src-web/components/Topology/viewer/defaults/titles";
@@ -9,19 +8,19 @@ const locale = "en-US";
 
 describe("getLegendTitle", () => {
   const titleMap = new Map([
-    ["deploymentconfig", "Deployment config"],
-    ["replicationcontroller", "Replication controller"],
+    ["deploymentconfig", "DeploymentConfig"],
+    ["replicationcontroller", "ReplicationController"],
     ["daemonset", "DaemonSet"],
     ["replicaset", "ReplicaSet"],
     ["configmap", "ConfigMap"],
-    ["customresource", "Custom resource"],
+    ["customresource", "CustomResource"],
     ["statefulset", "StatefulSet"],
-    ["storageclass", "Storage class"],
-    ["serviceaccount", "Service account"],
-    ["securitycontextconstraints", "Security Context Constraints"],
-    ["inmemorychannel", "In memory channel"],
-    ["integrationplatform", "Integration platform"],
-    ["persistentvolumeclaim", "Persistent Volume Claim"],
+    ["storageclass", "StorageClass"],
+    ["serviceaccount", "ServiceAccount"],
+    ["securitycontextconstraints", "SecurityContextConstraints"],
+    ["inmemorychannel", "InMemoryChannel"],
+    ["integrationplatform", "IntegrationPlatform"],
+    ["persistentvolumeclaim", "PersistentVolumeClaim"],
     ["application", "Application"],
     ["placements", "Placements"],
     ["unknown", "Unknown"],
