@@ -1,14 +1,17 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
  *  Copyright (c) 2020 Red Hat, Inc.
+ * Copyright Contributors to the Open Cluster Management project
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
 
 import {
+  getRepoTypeForArgoApplication,
   getSearchLinkForOneApplication,
+  getSearchLinkForArgoApplications,
   getAppOverviewCardsData
 } from "../../../../../src-web/components/common/ResourceOverview/utils";
 import {
@@ -211,6 +214,53 @@ const data2 = {
   related: []
 };
 
+describe("getRepoTypeForArgoApplication", () => {
+  it("should return git repo type for Argo application", () => {
+    expect(getRepoTypeForArgoApplication({ path: "helloworld" })).toEqual(
+      "git"
+    );
+  });
+  it("should return helm repo type for Argo application", () => {
+    expect(getRepoTypeForArgoApplication({ chart: "redis" })).toEqual(
+      "helmrepo"
+    );
+  });
+  it("should return empty string for Argo application repo type", () => {
+    expect(getRepoTypeForArgoApplication({})).toEqual("");
+  });
+});
+
+describe("getSearchLinkForArgoApplications", () => {
+  it("should return search link for Argo application", () => {
+    const source = {
+      path: "helloworld",
+      repoURL: "https://github.com/fxiang1/app-samples",
+      targetRevision: "HEAD"
+    };
+    const result =
+      '/search?filters={"textsearch":"kind%3Aapplication%20apigroup%3Aargoproj.io%20path%3Ahelloworld%20repoURL%3Ahttps%3A%2F%2Fgithub.com%2Ffxiang1%2Fapp-samples%20targetRevision%3AHEAD"}';
+    expect(getSearchLinkForArgoApplications(source)).toEqual(result);
+  });
+  it("should return search link for Argo application", () => {
+    const source = {
+      repoURL: "https://charts.bitnami.com/bitnami",
+      targetRevision: "12.2.4",
+      chart: "redis"
+    };
+    const result =
+      '/search?filters={"textsearch":"kind%3Aapplication%20apigroup%3Aargoproj.io%20repoURL%3Ahttps%3A%2F%2Fcharts.bitnami.com%2Fbitnami%20targetRevision%3A12.2.4%20chart%3Aredis"}';
+    expect(getSearchLinkForArgoApplications(source)).toEqual(result);
+  });
+  it("should return empty string for undefined resource", () => {
+    expect(getSearchLinkForArgoApplications(undefined)).toEqual("");
+  });
+  it("should return basic url for empty resource", () => {
+    const result =
+      '/search?filters={"textsearch":"kind%3Aapplication%20apigroup%3Aargoproj.io"}';
+    expect(getSearchLinkForArgoApplications({})).toEqual(result);
+  });
+});
+
 describe("getSearchLinkForOneApplication", () => {
   const appName = "test-app";
   const appNamespace = "default";
@@ -250,29 +300,31 @@ describe("getSearchLinkForOneApplication", () => {
 
 describe("getAppOverviewCardsData", () => {
   it("has topology and app data with local deployment and time window", () => {
-    const targetLink =
-      '/search?filters={"textsearch":"kind%3Aapplication%20name%3Aguestbook-app%20namespace%3Adefault"}';
     const appOverviewCardsData = getAppOverviewCardsData(
       reduxStoreAppPipelineWithCEM.HCMApplicationList,
       reduxStoreAppPipelineWithCEM.topology,
       "mortgage-app",
-      "default",
-      targetLink
+      "default"
     );
     const result = {
-      appName: "mortgage-app",
-      appNamespace: "default",
+      apiGroup: "app.k8s.io",
+      argoSource: {},
+      clusterNames: [],
       creationTimestamp: "Aug 13 2018, 3:23 pm",
+      destinationNs: "",
+      destinationCluster: "",
+      editArgoSetLink: "",
+      isArgoApp: false,
+      lastSyncedTimestamp: "Sep 13 2020, 2:25 pm",
       remoteClusterCount: 1,
       localClusterDeploy: false,
       nodeStatuses: { green: 0, yellow: 0, red: 0, orange: 3 },
-      targetLink: targetLink,
       subsList: [
         {
           name: "mortgage-app-subscription",
           resourceType: "GitHub",
           resourcePath: "https://github.com/fxiang1/app-samples.git",
-          gitBranch: "master",
+          gitBranch: "main",
           gitPath: "mortgage",
           package: "",
           packageFilterVersion: "",
@@ -288,29 +340,31 @@ describe("getAppOverviewCardsData", () => {
   });
 
   it("has missing channel data", () => {
-    const targetLink =
-      '/search?filters={"textsearch":"kind%3Aapplication%20name%3Aguestbook-app%20namespace%3Adefault"}';
     const appOverviewCardsData = getAppOverviewCardsData(
       testHCMAppList,
       topologyNoChannel,
       "mortgage-app",
-      "default",
-      targetLink
+      "default"
     );
     const result = {
-      appName: "mortgage-app",
-      appNamespace: "default",
+      apiGroup: "app.k8s.io",
+      argoSource: {},
+      clusterNames: [],
       creationTimestamp: "Aug 13 2018, 3:23 pm",
+      destinationNs: "",
+      destinationCluster: "",
+      editArgoSetLink: "",
+      isArgoApp: false,
+      lastSyncedTimestamp: "-",
       remoteClusterCount: 1,
       localClusterDeploy: false,
       nodeStatuses: { green: 0, yellow: 0, red: 0, orange: 3 },
-      targetLink: targetLink,
       subsList: [
         {
           name: "mortgage-app-subscription",
           resourceType: "",
           resourcePath: "",
-          gitBranch: "master",
+          gitBranch: "main",
           gitPath: "mortgage",
           package: "",
           packageFilterVersion: "",
@@ -326,23 +380,23 @@ describe("getAppOverviewCardsData", () => {
   });
 
   it("has no data", () => {
-    const targetLink =
-      '/search?filters={"textsearch":"kind%3Aapplication%20name%3Aguestbook-app%20namespace%3Adefault"}';
     const appOverviewCardsData = getAppOverviewCardsData(
       emptyData,
       emptyData,
       "mortgage-app",
-      "default",
-      targetLink
+      "default"
     );
     const result = {
-      appName: "mortgage-app",
-      appNamespace: "default",
+      argoSource: -1,
       creationTimestamp: -1,
+      destinationNs: -1,
+      destinationCluster: "",
+      editArgoSetLink: "",
+      isArgoApp: false,
+      lastSyncedTimestamp: -1,
       remoteClusterCount: -1,
       localClusterDeploy: false,
       nodeStatuses: -1,
-      targetLink: targetLink,
       subsList: -1
     };
 
@@ -355,28 +409,6 @@ const emptyItemsData = {
   items: []
 };
 
-// total: 12, running: 4, failed: 5
-const podSampleData = {
-  items: [
-    {
-      name: "app1",
-      namespace: "default",
-      podStatusCount: {
-        Running: 2,
-        Pass: 1,
-        Deployed: 1,
-        Pending: 1,
-        InProgress: 1,
-        Failed: 2,
-        Error: 2,
-        ImagePullBackoff: 1,
-        ContainerCreating: 1,
-        Ready: 2
-      }
-    }
-  ]
-};
-
 const testHCMAppList = {
   forceReload: false,
   items: [
