@@ -81,6 +81,7 @@ export interface ChartBulletProps {
    * it will be used as a nested object property path (for details see Lodash docs for _.get).
    * If `null` or `undefined`, the data value will be used as is (identity function/pass-through).
    *
+   * @propType number | string | Function | string[]
    * @example 0, 'y', 'y.value.nested.1.thing', 'y[2].also.nested', null, d => Math.sin(d)
    */
   comparativeErrorMeasureDataY?: DataGetterPropType;
@@ -120,6 +121,7 @@ export interface ChartBulletProps {
    * it will be used as a nested object property path (for details see Lodash docs for _.get).
    * If `null` or `undefined`, the data value will be used as is (identity function/pass-through).
    *
+   * @propType number | string | Function | string[]
    * @example 0, 'y', 'y.value.nested.1.thing', 'y[2].also.nested', null, d => Math.sin(d)
    */
   comparativeWarningMeasureDataY?: DataGetterPropType;
@@ -154,9 +156,12 @@ export interface ChartBulletProps {
    * If this prop is not provided, a domain will be calculated from data, or other
    * available information.
    *
-   * @example {x: [0, 2], y: [0, 100]}
-   *
    * Note: The x domain is expected to be `x: [0, 2]` in order to position all measures properly
+   *
+   * @propType number[] | { x: number[], y: number[] }
+   * @example [low, high], { x: [low, high], y: [low, high] }
+   *
+   * {x: [0, 2], y: [0, 100]}
    */
   domain?: DomainPropType;
   /**
@@ -244,7 +249,7 @@ export interface ChartBulletProps {
    * dependent variable. This may cause confusion in horizontal charts, as the independent variable will corresponds to
    * the y axis.
    *
-   * examples:
+   * @example
    *
    * maxDomain={0}
    * maxDomain={{ y: 0 }}
@@ -261,7 +266,7 @@ export interface ChartBulletProps {
    * dependent variable. This may cause confusion in horizontal charts, as the independent variable will corresponds to
    * the y axis.
    *
-   * examples:
+   * @example
    *
    * minDomain={0}
    * minDomain={{ y: 0 }}
@@ -277,6 +282,8 @@ export interface ChartBulletProps {
    *
    * Note: The underlying bullet chart is a different size than height and width. For a horizontal chart, left and right
    * padding may need to be applied at (approx) 2 to 1 scale.
+   *
+   * @propType number | { top: number, bottom: number, left: number, right: number }
    */
   padding?: PaddingProps;
   /**
@@ -301,6 +308,7 @@ export interface ChartBulletProps {
    * it will be used as a nested object property path (for details see Lodash docs for _.get).
    * If `null` or `undefined`, the data value will be used as is (identity function/pass-through).
    *
+   * @propType number | string | Function | string[]
    * @example 0, 'y', 'y.value.nested.1.thing', 'y[2].also.nested', null, d => Math.sin(d)
    */
   primaryDotMeasureDataY?: DataGetterPropType;
@@ -340,6 +348,7 @@ export interface ChartBulletProps {
    * it will be used as a nested object property path (for details see Lodash docs for _.get).
    * If `null` or `undefined`, the data value will be used as is (identity function/pass-through).
    *
+   * @propType number | string | Function | string[]
    * @example 0, 'y', 'y.value.nested.1.thing', 'y[2].also.nested', null, d => Math.sin(d)
    */
   primarySegmentedMeasureDataY?: DataGetterPropType;
@@ -379,6 +388,7 @@ export interface ChartBulletProps {
    * it will be used as a nested object property path (for details see Lodash docs for _.get).
    * If `null` or `undefined`, the data value will be used as is (identity function/pass-through).
    *
+   * @propType number | string | Function | string[]
    * @example 0, 'y', 'y.value.nested.1.thing', 'y[2].also.nested', null, d => Math.sin(d)
    */
   qualitativeRangeDataY?: DataGetterPropType;
@@ -387,6 +397,7 @@ export interface ChartBulletProps {
    * This prop is useful for defining custom baselines for components like ChartBar.
    * This prop may be given in a variety of formats.
    *
+   * @propType number | string | Function | string[]
    * @example 'last_quarter_profit', () => 10, 1, 'employees.salary', ["employees", "salary"]
    */
   qualitativeRangeDataY0?: DataGetterPropType;
@@ -417,6 +428,8 @@ export interface ChartBulletProps {
   /**
    * The theme prop specifies a theme to use for determining styles and layout properties for a component. Any styles or
    * props defined in theme may be overwritten by props specified on the component instance.
+   *
+   * @propType object
    */
   theme?: ChartThemeDefinition;
   /**
@@ -739,17 +752,21 @@ export const ChartBullet: React.FunctionComponent<ChartBulletProps> = ({
 
     // Adjust for padding
     if (legendPosition === ChartLegendPosition.bottom) {
-      dy = horizontal
-        ? defaultPadding.top * 0.5 + (defaultPadding.bottom * 0.5 - defaultPadding.bottom) - 25
-        : title
-        ? -defaultPadding.bottom + 60
-        : -defaultPadding.bottom;
+      if (horizontal) {
+        dy = defaultPadding.top * 0.5 + (defaultPadding.bottom * 0.5 - defaultPadding.bottom) - 25;
+      } else if (title) {
+        dy = -defaultPadding.bottom + 60;
+      } else {
+        dy = -defaultPadding.bottom;
+      }
     } else if (legendPosition === ChartLegendPosition.bottomLeft) {
-      dy = horizontal
-        ? defaultPadding.top * 0.5 + (defaultPadding.bottom * 0.5 - defaultPadding.bottom) - 25
-        : title
-        ? -defaultPadding.bottom + 60
-        : -defaultPadding.bottom;
+      if (horizontal) {
+        dy = defaultPadding.top * 0.5 + (defaultPadding.bottom * 0.5 - defaultPadding.bottom) - 25;
+      } else if (title) {
+        dy = -defaultPadding.bottom + 60;
+      } else {
+        dy = -defaultPadding.bottom;
+      }
       dx = -10;
     }
     return getComputedLegend({
@@ -769,12 +786,19 @@ export const ChartBullet: React.FunctionComponent<ChartBulletProps> = ({
   // Returns comparative zero measure
   const getComparativeZeroMeasure = () => {
     const _domain: any = domain;
-    const low = Array.isArray(_domain) ? _domain[0] : _domain.y && Array.isArray(_domain.y) ? _domain.y[0] : 0;
-    const high = Array.isArray(_domain)
-      ? _domain[_domain.length - 1]
-      : _domain.y && Array.isArray(_domain.y)
-      ? _domain.y[_domain.y.length - 1]
-      : 0;
+    let low = 0;
+    if (Array.isArray(_domain)) {
+      low = _domain[0];
+    } else if (_domain.y && Array.isArray(_domain.y)) {
+      low = _domain.y[0];
+    }
+
+    let high = 0;
+    if (Array.isArray(_domain)) {
+      high = _domain[_domain.length - 1];
+    } else if (_domain.y && Array.isArray(_domain.y)) {
+      high = _domain.y[_domain.y.length - 1];
+    }
 
     if (low < 0 && high > 0) {
       return comparativeZeroMeasure;
