@@ -1,7 +1,6 @@
 var _curry2 = require('./internal/_curry2');
-var _slice = require('./internal/_slice');
+var _isFunction = require('./internal/_isFunction');
 var curryN = require('./curryN');
-var is = require('./is');
 var toString = require('./toString');
 
 
@@ -27,12 +26,15 @@ var toString = require('./toString');
  *      sliceFrom(6, 'abcdefghijklm'); //=> 'ghijklm'
  *      var sliceFrom6 = R.invoker(2, 'slice')(6);
  *      sliceFrom6(8, 'abcdefghijklm'); //=> 'gh'
+ * @symb R.invoker(0, 'method')(o) = o['method']()
+ * @symb R.invoker(1, 'method')(a, o) = o['method'](a)
+ * @symb R.invoker(2, 'method')(a, b, o) = o['method'](a, b)
  */
 module.exports = _curry2(function invoker(arity, method) {
   return curryN(arity + 1, function() {
     var target = arguments[arity];
-    if (target != null && is(Function, target[method])) {
-      return target[method].apply(target, _slice(arguments, 0, arity));
+    if (target != null && _isFunction(target[method])) {
+      return target[method].apply(target, Array.prototype.slice.call(arguments, 0, arity));
     }
     throw new TypeError(toString(target) + ' does not have a method named "' + method + '"');
   });
