@@ -1,4 +1,5 @@
-var _curry2 = /*#__PURE__*/require('./internal/_curry2');
+var _curry2 = require('./internal/_curry2');
+
 
 /**
  * Sorts a list according to a list of comparators.
@@ -7,35 +8,33 @@ var _curry2 = /*#__PURE__*/require('./internal/_curry2');
  * @memberOf R
  * @since v0.23.0
  * @category Relation
- * @sig [(a, a) -> Number] -> [a] -> [a]
+ * @sig [a -> a -> Number] -> [a] -> [a]
  * @param {Array} functions A list of comparator functions.
  * @param {Array} list The list to sort.
  * @return {Array} A new list sorted according to the comarator functions.
  * @example
  *
- *      const alice = {
+ *      var alice = {
  *        name: 'alice',
  *        age: 40
  *      };
- *      const bob = {
+ *      var bob = {
  *        name: 'bob',
  *        age: 30
  *      };
- *      const clara = {
+ *      var clara = {
  *        name: 'clara',
  *        age: 40
  *      };
- *      const people = [clara, bob, alice];
- *      const ageNameSort = R.sortWith([
+ *      var people = [clara, bob, alice];
+ *      var ageNameSort = R.sortWith([
  *        R.descend(R.prop('age')),
  *        R.ascend(R.prop('name'))
  *      ]);
  *      ageNameSort(people); //=> [alice, clara, bob]
  */
-
-
-var sortWith = /*#__PURE__*/_curry2(function sortWith(fns, list) {
-  return Array.prototype.slice.call(list, 0).sort(function (a, b) {
+module.exports = _curry2(function sortWith(fns, list) {
+  return Array.prototype.slice.call(list, 0).sort(function(a, b) {
     var result = 0;
     var i = 0;
     while (result === 0 && i < fns.length) {
@@ -45,4 +44,3 @@ var sortWith = /*#__PURE__*/_curry2(function sortWith(fns, list) {
     return result;
   });
 });
-module.exports = sortWith;
\ No newline at end of file
